==> huaweicloudsdkconfig-3.1.141-py2.py3-none-any.whl: huaweicloudsdkconfig/v1/model/update_conformance_pack_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateConformancePackRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'conformance_pack_id': 'str',
        'body': 'UpdateConformancePackRequestBody'
    }

    attribute_map = {
        'conformance_pack_id': 'conformance_pack_id',
        'body': 'body'
    }

    def __init__(self, conformance_pack_id=None, body=None):
        """UpdateConformancePackRequest

        The model defined in huaweicloud sdk

        :param conformance_pack_id: 合规规则包ID。
        :type conformance_pack_id: str
        :param body: Body of the UpdateConformancePackRequest
        :type body: :class:`huaweicloudsdkconfig.v1.UpdateConformancePackRequestBody`
        """
        
        

        self._conformance_pack_id = None
        self._body = None
        self.discriminator = None

        self.conformance_pack_id = conformance_pack_id
        if body is not None:
            self.body = body

    @property
    def conformance_pack_id(self):
        """Gets the conformance_pack_id of this UpdateConformancePackRequest.

        合规规则包ID。

        :return: The conformance_pack_id of this UpdateConformancePackRequest.
        :rtype: str
        """
        return self._conformance_pack_id

    @conformance_pack_id.setter
    def conformance_pack_id(self, conformance_pack_id):
        """Sets the conformance_pack_id of this UpdateConformancePackRequest.

        合规规则包ID。

        :param conformance_pack_id: The conformance_pack_id of this UpdateConformancePackRequest.
        :type conformance_pack_id: str
        """
        self._conformance_pack_id = conformance_pack_id

    @property
    def body(self):
        """Gets the body of this UpdateConformancePackRequest.

        :return: The body of this UpdateConformancePackRequest.
        :rtype: :class:`huaweicloudsdkconfig.v1.UpdateConformancePackRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateConformancePackRequest.

        :param body: The body of this UpdateConformancePackRequest.
        :type body: :class:`huaweicloudsdkconfig.v1.UpdateConformancePackRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateConformancePackRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkconfig-3.1.146-py2.py3-none-any.whl: huaweicloudsdkconfig/v1/model/update_conformance_pack_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateConformancePackRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'conformance_pack_id': 'str',
        'body': 'UpdateConformancePackRequestBody'
    }

    attribute_map = {
        'conformance_pack_id': 'conformance_pack_id',
        'body': 'body'
    }

    def __init__(self, conformance_pack_id=None, body=None):
        r"""UpdateConformancePackRequest

        The model defined in huaweicloud sdk

        :param conformance_pack_id: 合规规则包ID。
        :type conformance_pack_id: str
        :param body: Body of the UpdateConformancePackRequest
        :type body: :class:`huaweicloudsdkconfig.v1.UpdateConformancePackRequestBody`
        """
        
        

        self._conformance_pack_id = None
        self._body = None
        self.discriminator = None

        self.conformance_pack_id = conformance_pack_id
        if body is not None:
            self.body = body

    @property
    def conformance_pack_id(self):
        r"""Gets the conformance_pack_id of this UpdateConformancePackRequest.

        合规规则包ID。

        :return: The conformance_pack_id of this UpdateConformancePackRequest.
        :rtype: str
        """
        return self._conformance_pack_id

    @conformance_pack_id.setter
    def conformance_pack_id(self, conformance_pack_id):
        r"""Sets the conformance_pack_id of this UpdateConformancePackRequest.

        合规规则包ID。

        :param conformance_pack_id: The conformance_pack_id of this UpdateConformancePackRequest.
        :type conformance_pack_id: str
        """
        self._conformance_pack_id = conformance_pack_id

    @property
    def body(self):
        r"""Gets the body of this UpdateConformancePackRequest.

        :return: The body of this UpdateConformancePackRequest.
        :rtype: :class:`huaweicloudsdkconfig.v1.UpdateConformancePackRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateConformancePackRequest.

        :param body: The body of this UpdateConformancePackRequest.
        :type body: :class:`huaweicloudsdkconfig.v1.UpdateConformancePackRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateConformancePackRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
